﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.Globalization;
using System.Configuration;
using System.Collections;

namespace CCDWareXMLDeregionalizer
{
   

    public partial class Form1 : Form
    {
        public string InputFile;
        public int counter;

        public Form1()
        {
            InitializeComponent();
            InputFile = "";

            GetCountryList();

            txtFilename.Text = Properties.Settings.Default.Filename;
            InputFile = txtFilename.Text;
            txtLangTarget.Text = Properties.Settings.Default.LangDest;
            txtCultureInput.Text = Properties.Settings.Default.LangSource;

            cmbInput.SelectedIndex = Properties.Settings.Default.LangSrcIdx;
            cmbLangTarget.SelectedIndex = Properties.Settings.Default.LangDestIdx;

         
        }

        string ToTargetNumber(string value)
        {
            CultureInfo target = CultureInfo.CreateSpecificCulture(txtLangTarget.Text);

            if (value.IndexOf(target.NumberFormat.NumberDecimalSeparator) == -1)
            {
                double ra = Double.Parse(value, CultureInfo.CreateSpecificCulture(txtCultureInput.Text));
                counter++;
                return ra.ToString(CultureInfo.CreateSpecificCulture(txtLangTarget.Text));
            }
            else
                return value;
        }

        void Transform()
        {
            XmlDocument myXmlDocument = new XmlDocument();
            myXmlDocument.Load(InputFile);

            counter = 0;

            XmlNode node; node = myXmlDocument.DocumentElement;

            foreach (XmlNode node1 in node.ChildNodes)
                foreach (XmlNode node2 in node1.ChildNodes)
                    if (node2.Name == "RA" || node2.Name == "DC")
                    {                        
                        node2.InnerText = ToTargetNumber(node2.InnerText);
                    }

            string TargetFile =                
                System.IO.Path.GetDirectoryName(InputFile) +
                System.IO.Path.DirectorySeparatorChar +
                System.IO.Path.GetFileNameWithoutExtension(InputFile) + "-" + txtLangTarget.Text +
                System.IO.Path.GetExtension(InputFile);
            
            myXmlDocument.Save(TargetFile);

            MessageBox.Show(counter.ToString() + " fields converted. \nFile saved as " + TargetFile);
            
        }

        private void btnInput_Click(object sender, EventArgs e)
        {
            OpenFileDialog openFileDialog1 = new OpenFileDialog();
            openFileDialog1.Filter = "XML files (*.xml)|*.xml|All files (*.*)|*.*";
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                InputFile = openFileDialog1.FileName;
                txtFilename.Text = InputFile;
            }


        }

        private void btnDoWork_Click(object sender, EventArgs e)
        {
            if (!System.IO.File.Exists(txtFilename.Text))
            {
                MessageBox.Show("Input file does not exist");
                return;
            }

            if (txtCultureInput.Text == String.Empty)
            {
                MessageBox.Show("Please select input language");
                return;
            }

            if (txtLangTarget.Text == String.Empty)
            {
                MessageBox.Show("Please select target language");
                return;
            }

            Properties.Settings.Default.Filename = txtFilename.Text;
            Properties.Settings.Default.LangDest = txtLangTarget.Text;
            Properties.Settings.Default.LangSource = txtCultureInput.Text;
            Properties.Settings.Default.LangDestIdx = cmbLangTarget.SelectedIndex;
            Properties.Settings.Default.LangSrcIdx = cmbInput.SelectedIndex;

            Properties.Settings.Default.Save();

            Transform();
        }


        /// <summary>
        /// method for generating a country list, say for populating
        /// a ComboBox, with country options. We return the
        /// values in a Generic List<T>
        /// </summary>
        /// <returns></returns>
        public  void GetCountryList()
        {
            //create a new Generic list to hold the country names returned
            List<string> cultureList = new List<string>();

            //create an array of CultureInfo to hold all the cultures found, these include the users local cluture, and all the
            //cultures installed with the .Net Framework
            CultureInfo[] cultures = CultureInfo.GetCultures(CultureTypes.AllCultures & ~CultureTypes.NeutralCultures);

            //loop through all the cultures found
            foreach (CultureInfo culture in cultures)
            {
                //pass the current culture's Locale ID (http://msdn.microsoft.com/en-us/library/0h88fahh.aspx)
                //to the RegionInfo contructor to gain access to the information for that culture
                try
                {
                    RegionInfo region = new RegionInfo(culture.LCID);

                    //make sure out generic list doesnt already
                    //contain this country
                    if (!(cultureList.Contains(region.DisplayName)))
                        //not there so add the EnglishName (http://msdn.microsoft.com/en-us/library/system.globalization.regioninfo.englishname.aspx)
                        //value to our generic list
                        cultureList.Add(region.EnglishName);
                        ComboboxItem item = new ComboboxItem();
                        item.Text = region.DisplayName;
                        item.Value = culture.Name;
                        cmbInput.Items.Add(item);
                        cmbLangTarget.Items.Add(item);
                }
                catch { }
            }            
        }

        private void cmbInput_SelectedIndexChanged(object sender, EventArgs e)
        {
            txtCultureInput.Text = (cmbInput.SelectedItem as ComboboxItem).Value.ToString();
           
        }

        private void cmbLangTarget_SelectedIndexChanged(object sender, EventArgs e)
        {
            txtLangTarget.Text = (cmbLangTarget.SelectedItem as ComboboxItem).Value.ToString();
        }
       
    }
    public class ComboboxItem
    {
        public string Text { get; set; }
        public object Value { get; set; }

        public override string ToString()
        {
            return Text;
        }
    }
}
